Coverage for src/rev/Matrices.py: 67%

# Coverage for src/rev/Matrices.py : 67%

## 18 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1#!/usr/bin/env python3

2

3 import numpy as np

4 from FADiff import FADiff

5

6

7 class Vect:

8 def __init__(self):

9 pass

10

11 def __sub__(self, other):

12 pass

13

14 def __rsub__(self, other):

15 return self.__sub__(other)

16

17 @property

18 def val(self):

19 pass

20

21 @property

22 def der(self):

23 pass

24

25 @staticmethod

26 def _set_parents(var1, var2=None):

27 pass